Welcome to pytsql's documentation!
===================================

``pytsql`` allows to run mssql scripts, typically run from GUIs, from Python.

This, in turn, eases concurrent, scheduled and chained execution of scripts in a
workflow. Put differently, it enables automated execution of Microsoft sql server scripts.

Moreover, ``pytsql`` supports parametrization of scripts, akin to templating.

Contents
--------

.. toctree::

   installation
   usage
   development

   API Reference <api/pytsql.rst>
